Struct
QmiMessageFoxSetFccAuthenticationOutput
since: 1.38
Description [src]
struct QmiMessageFoxSetFccAuthenticationOutput {
/* No available fields */
}
The QmiMessageFoxSetFccAuthenticationOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_message_fox_set_fcc_authentication_output_get_result
Get the result of the QMI operation.
since: 1.38
qmi_message_fox_set_fcc_authentication_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_fox_set_fcc_authentication_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38